@@ -1,5 +1,5 @@
 def is_selectable(obj):
     try:
         return obj not in (None, [], (), {}, set())
-    except ValueError:
+    except Exception:
         return True
